@@ -18,7 +18,7 @@ class ModifyAnnotationPropertiesTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void initTestCase();
     void cleanupTestCase();
     void init();
