@@ -12,6 +12,7 @@
 #ifndef _OKULAR_GENERATOR_H_
 #define _OKULAR_GENERATOR_H_
 
+#include "action.h"
 #include "document.h"
 #include "fontinfo.h"
 #include "global.h"
@@ -361,6 +362,32 @@ public:
      */
     virtual const QList<EmbeddedFile *> *embeddedFiles() const;
 
+    /**
+     * This enum identifies default page layouts.
+     *
+     * @since 24.12
+     */
+    enum PageLayout {
+        NoLayout = -1, ///< Layout not specified
+        SinglePage,    ///< Display a single page
+        TwoPageLeft,   ///< Display the pages in two columns, with odd-numbered pages on the left
+        TwoPageRight   ///< Display the pages in two columns, with odd-numbered pages on the right
+    };
+
+    /**
+     * This method returns the default page layout.
+     *
+     * @since 24.12
+     */
+    virtual PageLayout defaultPageLayout() const;
+
+    /**
+     * This method returns if the default page layout is continuous.
+     *
+     * @since 24.12
+     */
+    virtual bool defaultPageContinuous() const;
+
     /**
      * This enum identifies the metric of the page size.
      */
@@ -447,9 +474,9 @@ public:
     virtual QAbstractItemModel *layersModel() const;
 
     /**
-     * Calls the backend to execute an BackendOpaqueAction
+     * Calls the backend to execute a BackendOpaqueAction @p action and returns BackendOpaqueAction result
      */
-    virtual void opaqueAction(const BackendOpaqueAction *action);
+    virtual BackendOpaqueAction::OpaqueActionResult opaqueAction(const BackendOpaqueAction *action);
 
     /**
      * Frees the contents of the opaque action (if any);
@@ -458,6 +485,13 @@ public:
      */
     virtual void freeOpaqueActionContents(const BackendOpaqueAction &action);
 
+    /**
+     * Retrieves the additional document action for the specified @p type .
+     *
+     * @since 24.08
+     */
+    virtual Okular::Action *additionalDocumentAction(Document::DocumentAdditionalActionType type);
+
 Q_SIGNALS:
     /**
      * This signal should be emitted whenever an error occurred in the generator.
