@@ -192,16 +192,40 @@ void JSField::setValue(const QJSValue &value)
     }
     case FormField::FormText: {
         FormFieldText *textField = static_cast<FormFieldText *>(m_field);
-        const QString text = value.toString();
-        if (text != textField->text()) {
-            textField->setText(text);
-            updateField(m_field);
+        Page *page = g_fieldCache->value(m_field);
+        if (page) {
+            Document *doc = PagePrivate::get(page)->m_doc->m_parent;
+            const QString text = value.toString();
+            if (text != textField->text()) {
+                textField->setText(text);
+            }
+            doc->processKVCFActions(textField);
+        } else {
+            qWarning() << "Could not get page of field" << m_field;
         }
         break;
     }
     case FormField::FormChoice: {
         FormFieldChoice *choice = static_cast<FormFieldChoice *>(m_field);
-        Q_UNUSED(choice); // ###
+        if (choice->choiceType() == FormFieldChoice::ComboBox) {
+            const QString text = value.toString();
+            Page *page = g_fieldCache->value(m_field);
+            if (page) {
+                Document *doc = PagePrivate::get(page)->m_doc->m_parent;
+                const int idx = choice->choices().indexOf(text);
+                if (idx == -1) {
+                    if (choice->isEditable()) {
+                        choice->setEditChoice(text);
+                        doc->processKVCFActions(choice);
+                    } else {
+                        qWarning() << "Set not possible, invalid or unknown";
+                    }
+                } else {
+                    choice->setCurrentChoices({idx});
+                    doc->processKVCFActions(choice);
+                }
+            }
+        }
         break;
     }
     case FormField::FormSignature: {
