@@ -106,7 +106,7 @@ Okular::TextPage *TextDocumentGeneratorPrivate::createTextPage(int pageNumber) c
                     text = QStringLiteral("\n");
                 }
 
-                textPage->append(text, new Okular::NormalizedRect(rect.left(), rect.top(), rect.right(), rect.bottom()));
+                textPage->append(text, Okular::NormalizedRect(rect.left(), rect.top(), rect.right(), rect.bottom()));
             }
         }
     }
@@ -166,9 +166,7 @@ QList<TextDocumentGeneratorPrivate::LinkInfo> TextDocumentGeneratorPrivate::gene
 {
     QList<LinkInfo> result;
 
-    for (int i = 0; i < mLinkPositions.count(); ++i) {
-        const LinkPosition &linkPosition = mLinkPositions[i];
-
+    for (const LinkPosition &linkPosition : mLinkPositions) {
         const QVector<QRectF> rects = TextDocumentUtils::calculateBoundingRects(mDocument, linkPosition.startPosition, linkPosition.endPosition);
 
         for (int i = 0; i < rects.count(); ++i) {
@@ -292,11 +290,11 @@ Document::OpenResult TextDocumentGenerator::loadDocumentWithPassword(const QStri
 
         // loading failed, cleanup all the stuff eventually gathered from the converter
         d->mTitlePositions.clear();
-        for (const TextDocumentGeneratorPrivate::LinkPosition &linkPos : qAsConst(d->mLinkPositions)) {
+        for (const TextDocumentGeneratorPrivate::LinkPosition &linkPos : std::as_const(d->mLinkPositions)) {
             delete linkPos.link;
         }
         d->mLinkPositions.clear();
-        for (const TextDocumentGeneratorPrivate::AnnotationPosition &annPos : qAsConst(d->mAnnotationPositions)) {
+        for (const TextDocumentGeneratorPrivate::AnnotationPosition &annPos : std::as_const(d->mAnnotationPositions)) {
             delete annPos.annotation;
         }
         d->mAnnotationPositions.clear();
@@ -562,7 +560,7 @@ void TextDocumentGenerator::setTextDocument(QTextDocument *textDocument)
 
     d->mDocument = textDocument;
 
-    for (Page *p : qAsConst(d->m_document->m_pagesVector)) {
+    for (Page *p : std::as_const(d->m_document->m_pagesVector)) {
         p->setTextPage(nullptr);
     }
 }
