@@ -603,6 +603,11 @@ Okular::Action *createLinkFromPopplerLink(std::variant<const Poppler::Link *, st
         auto popplerLinkResetForm = toSharedPointer<const Poppler::LinkResetForm>(std::move(uniquePopplerLink));
         link->setNativeHandle(popplerLinkResetForm);
     } break;
+#endif
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(24, 10, 0)
+    case Poppler::Link::SubmitForm: {
+        // TODO
+    } break;
 #endif
     }
 
