@@ -43,6 +43,8 @@ public:
 
     void reparseConfig();
 
+    QAbstractItemModel *annotationsModel() const;
+
 public Q_SLOTS:
     void slotPageEnabled(bool);
     void slotAuthorEnabled(bool);
@@ -57,6 +59,8 @@ private Q_SLOTS:
     void activated(const QModelIndex &);
     void contextMenuRequested(const QPoint);
     void saveSearchOptions();
+    void saveTreeState();
+    void restoreTreeState();
 
 private:
     QModelIndexList retrieveAnnotations(const QModelIndex &idx) const;
@@ -64,6 +68,7 @@ private:
     // data fields (GUI)
     KTreeViewSearchLine *m_searchLine;
     TreeView *m_view;
+    QStringList m_expansionKeys;
     // internal storage
     Okular::Document *m_document;
     AnnotationModel *m_model;
